Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1094)

Unified Diff: third_party/WebKit/Source/core/layout/LayoutObject.h

Issue 2758683002: Replace ASSERT_NOT_REACHED with NOTREACHED in core/layout/ (Closed)
Patch Set: Rebase with latest Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/LayoutObject.h
diff --git a/third_party/WebKit/Source/core/layout/LayoutObject.h b/third_party/WebKit/Source/core/layout/LayoutObject.h
index ac9462f73910d0dbe23ccc828005c2807dda3866..15138df96169f41959ea37da48ae7eceb7d663cf 100644
--- a/third_party/WebKit/Source/core/layout/LayoutObject.h
+++ b/third_party/WebKit/Source/core/layout/LayoutObject.h
@@ -326,7 +326,7 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
#ifndef NDEBUG
if (paintInvalidationStateIsDirty()) {
showLayoutTreeForThis();
- ASSERT_NOT_REACHED();
+ NOTREACHED();
}
#endif
}
@@ -603,7 +603,7 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
// FIXME: Until all SVG layoutObjects can be subclasses of
// LayoutSVGModelObject we have to add SVG layoutObject methods to
// LayoutObject with an ASSERT_NOT_REACHED() default implementation.
bool isSVG() const { return isOfType(LayoutObjectSVG); }
bool isSVGRoot() const { return isOfType(LayoutObjectSVGRoot); }
bool isSVGChild() const { return isSVG() && !isSVGRoot(); }
@@ -603,7 +603,7 @@ class CORE_EXPORT LayoutObject : public ImageResourceObserver,
// FIXME: Until all SVG layoutObjects can be subclasses of
// LayoutSVGModelObject we have to add SVG layoutObject methods to
- // LayoutObject with an ASSERT_NOT_REACHED() default implementation.
+ // LayoutObject with an NOTREACHED() default implementation.
bool isSVG() const { return isOfType(LayoutObjectSVG); }
bool isSVGRoot() const { return isOfType(LayoutObjectSVGRoot); }

Powered by Google App Engine
This is Rietveld 408576698